@@ -21,12 +21,19 @@ class BaseValidation():
         }
 
 
+def _get_sheet_name(field_name):
+    # TODO: Avoid sheet name collisions.
+    # https://github.com/hubmapconsortium/tableschema-to-template/issues/9
+    sheet_name = f'{field_name} list'
+    if len(sheet_name) <= 31:
+        return sheet_name
+    return f'{sheet_name[:15]}-{sheet_name[-15:]}'
+
+
 class EnumValidation(BaseValidation):
     def get_data_validation(self):
         enum = self.field['constraints']['enum']
-        name = f"{self.field['name']} list"[:31]
-        # TODO: Warn if sheet names collide.
-        # https://github.com/hubmapconsortium/tableschema-to-template/issues/9
+        name = _get_sheet_name(self.field['name'])
         enum_sheet = self.workbook.add_worksheet(name)
         for i, value in enumerate(enum):
             enum_sheet.write(i, 0, value)
